# Tasseled Cap - Landsat 5 TM v.1
# Created by:  Nathan Jennings
# Created on: 02.01.2011
# Updated on: 02.02.2011

'''
This algorithm uses the coefficients developed after Crist and Kauth, 1986
Tasseled Cap Transformation for Landsat TM and ArcGIS 10 Spatial Analyst
Map Algebra functions to compute the brightness, greenness, and wetness
components of a Landsat image.

Crist, E.P. and R. J. Kauth, 1986, "The Tasseled Cap De-mystified,"
Photogrammetric Engineering and Remote Sensing, 52(1):81-86.

This version assumes a 6 band Thematic Mapper image is used.
Data paths can be changed as necessary to poin to other data.
Also, the brightness and output images should be changed for each
new iteration of the routine.

NOTE: No data checking has been put in place.  The user must delete data
manually when running this algorithm more than one time.

Supports ArcGIS 10 and Python 2.6.5 or later
Requires Spatial Analyst Extension

'''



import arcpy, sys, traceback
from arcpy.sa import *

# set the current workspace (in the case a folder)
#!!!!!!!  The folder location for the workspace must point to the Data folder for unit 3  !!!!!!!
arcpy.env.workspace = 'C:\\GTCM\\3 - Sensor Platforms_Image Processing Basics_Band Ratios\\Data\\'

# Check out the Spatial Analysis Extension
arcpy.CheckOutExtension("spatial")

brightbnd = 'bright1.img'
greenbnd = 'green1.img'
wetbnd = 'wet1.img'
in_image = 'tm_sacsub.img\\'

bands = ['Layer_1',
         'Layer_2',
         'Layer_3',
         'Layer_4',
         'Layer_5',
         'Layer_6']

tasseled_cap = 'tc1.img'

print 'Running tasseled cap'

# Order of coefficients are TM1, TM2, TM3, TM4, TM5, TM7

bright = [0.2909, 
          0.2493,  
          0.4806,
          0.5568,
          0.4438,
          0.1706]

green = [-0.2728,
         -0.2174,
         -0.5508,
         0.7221,
         0.0733,
         -0.1648]

wet = [0.1466,
       0.1761,
       0.3322,
       0.3396,
       -0.6210,
       -0.4186]

tc_bright = Float(Raster(in_image + bands[0]) * bright[0] + \
            Raster(in_image + bands[1]) * bright[1] + \
            Raster(in_image + bands[2]) * bright[2] + \
            Raster(in_image + bands[3]) * bright[3] + \
            Raster(in_image + bands[4]) * bright[4] + \
            Raster(in_image + bands[5]) * bright[5])

tc_bright.save(brightbnd)

tc_green = Float(Raster(in_image + bands[0]) * green[0] + \
            Raster(in_image + bands[1]) * green[1] + \
            Raster(in_image + bands[2]) * green[2] + \
            Raster(in_image + bands[3]) * green[3] + \
            Raster(in_image + bands[4]) * green[4] + \
            Raster(in_image + bands[5]) * green[5])

tc_green.save(greenbnd)

tc_wet = Float(Raster(in_image + bands[0]) * wet[0] + \
            Raster(in_image + bands[1]) * wet[1] + \
            Raster(in_image + bands[2]) * wet[2] + \
            Raster(in_image + bands[3]) * wet[3] + \
            Raster(in_image + bands[4]) * wet[4] + \
            Raster(in_image + bands[5]) * wet[5])

tc_wet.save(wetbnd)


#Build the image using Composite Bands
arcpy.CompositeBands_management(brightbnd + ';' + \
                                greenbnd + ';' + \
                                wetbnd, tasseled_cap)

print 'Finished Tasseled Cap'
